<?php // plugin settings

if (!defined('ABSPATH')) exit;

function disable_media_sizes_options() {
	
	return array(
		
		'disable-size-thumbnail'    => 0,
		'disable-size-medium'       => 0,
		'disable-size-large'        => 0,
		'disable-size-medium-large' => 0,
		'disable-size-1536x1536'    => 0,
		'disable-size-2048x2048'    => 0,
		'disable-size-big'          => 0,
		
	);
	
}

function disable_media_sizes_get_options() {
	
	return get_option('disable_media_sizes_options', disable_media_sizes_options());
	
}

function disable_media_sizes_menu_page() {
	
	// add_options_page( $page_title, $menu_title, $capability, $menu_slug, $function )
	add_options_page('Disable Media Sizes', 'Disable Media Sizes', 'manage_options', 'disable-media-sizes', 'disable_media_sizes_display_settings');
	
}

function disable_media_sizes_display_settings() { ?>
	
	<div class="wrap">
		<h1><?php _e('Disable Media Sizes', 'disable-media-sizes'); ?></h1>
		<p>
			Below you can choose which image sizes should <strong>not</strong> be automatically generated by WordPress. 
			<a target="_blank" rel="noopener noreferrer" href="https://perishablepress.com/disable-wordpress-generated-images/" title="How to Disable WordPress Automatically Generated Images">More info&nbsp;&raquo;</a>
		</p>
		<p>
			<strong>Note:</strong> It is recommended to enable at least one smaller size image, so WordPress can use it for thumbnails in the Admin Area. 
		</p>
		<form method="post" action="options.php">
			
			<?php 
				settings_fields('disable_media_sizes_options');
				do_settings_sections('disable_media_sizes_options');
				submit_button();
			?>
			
		</form>
	</div>
	
<?php }

function disable_media_sizes_register_settings() {
	
	// register_setting( $option_group, $option_name, $sanitize_callback );
	register_setting('disable_media_sizes_options', 'disable_media_sizes_options', 'disable_media_sizes_validate_options');
	
	// add_settings_section( $id, $title, $callback, $page ); 
	add_settings_section('settings_1', 'Media Sizes', 'disable_media_sizes_settings_section_1', 'disable_media_sizes_options');
	
	// add_settings_field( $id, $title, $callback, $page, $section, $args );
	add_settings_field('disable-size-thumbnail',  'Disable Thumbnail Size', 'disable_media_sizes_callback_checkbox', 'disable_media_sizes_options', 'settings_1', array('id' => 'disable-size-thumbnail',    'label' => 'Prevent WordPress from generating thumbnail images'));
	add_settings_field('disable-size-medium',     'Disable Medium Size',    'disable_media_sizes_callback_checkbox', 'disable_media_sizes_options', 'settings_1', array('id' => 'disable-size-medium',       'label' => 'Prevent WordPress from generating medium images'));
	add_settings_field('disable-size-large',      'Disable Large Size',     'disable_media_sizes_callback_checkbox', 'disable_media_sizes_options', 'settings_1', array('id' => 'disable-size-large',        'label' => 'Prevent WordPress from generating large images'));
	
	// add_settings_section( $id, $title, $callback, $page ); 
	add_settings_section('settings_2', 'Other Sizes', 'disable_media_sizes_settings_section_2', 'disable_media_sizes_options');
	
	add_settings_field('disable-size-medium-large', 'Disable Medium Large',   'disable_media_sizes_callback_checkbox', 'disable_media_sizes_options', 'settings_2', array('id' => 'disable-size-medium-large', 'label' => 'Prevent WordPress from generating medium-large (768px) images'));
	add_settings_field('disable-size-1536x1536',    'Disable 1536x1536 Size', 'disable_media_sizes_callback_checkbox', 'disable_media_sizes_options', 'settings_2', array('id' => 'disable-size-1536x1536',    'label' => 'Prevent WordPress from generating 1536x1536 images'));
	add_settings_field('disable-size-2048x2048',    'Disable 2048x2048 Size', 'disable_media_sizes_callback_checkbox', 'disable_media_sizes_options', 'settings_2', array('id' => 'disable-size-2048x2048',    'label' => 'Prevent WordPress from generating 2048x2048 images'));
	add_settings_field('disable-size-big',          'Disable "Big" Size',     'disable_media_sizes_callback_checkbox', 'disable_media_sizes_options', 'settings_2', array('id' => 'disable-size-big',          'label' => 'Prevent WordPress from generating "big" (scaled) size images'));
	
}

function disable_media_sizes_validate_options($input) {
	
	if (isset($input['disable-size-thumbnail']))    $input['disable-size-thumbnail']    = sanitize_text_field(trim($input['disable-size-thumbnail']));
	if (isset($input['disable-size-medium']))       $input['disable-size-medium']       = sanitize_text_field(trim($input['disable-size-medium']));
	if (isset($input['disable-size-large']))        $input['disable-size-large']        = sanitize_text_field(trim($input['disable-size-large']));
	if (isset($input['disable-size-medium-large'])) $input['disable-size-medium-large'] = sanitize_text_field(trim($input['disable-size-medium-large']));
	if (isset($input['disable-size-1536x1536']))    $input['disable-size-1536x1536']    = sanitize_text_field(trim($input['disable-size-1536x1536']));
	if (isset($input['disable-size-2048x2048']))    $input['disable-size-2048x2048']    = sanitize_text_field(trim($input['disable-size-2048x2048']));
	if (isset($input['disable-size-big']))          $input['disable-size-big']          = sanitize_text_field(trim($input['disable-size-big']));
	
	return $input;
	
}

function disable_media_sizes_settings_section_1() {
	
	echo 'These sizes are set under WP Menu &gt; Settings &gt; Media &gt; Image sizes.';
	
}

function disable_media_sizes_settings_section_2() {
	
	echo 'These are the additional image sizes that WordPress generates quietly behind the scenes.';
	
}

function disable_media_sizes_callback_checkbox($args) {
	
	$options = disable_media_sizes_get_options();
	
	$id    = isset($args['id'])    ? $args['id']    : '';
	$label = isset($args['label']) ? $args['label'] : '';
	$value = isset($options[$id])  ? $options[$id]  : '';
	
	$name = 'disable_media_sizes_options['. $id .']';
	
	echo '<input id="'. esc_attr($name) .'" name="'. esc_attr($name) .'" type="checkbox" '. checked($value, 1, false) .' value="1"> ';
	echo '<label for="'. esc_attr($name) .'" class="inline-block">'. $label .'</label>';
	
}